==> eiffelstudio-18.11.10.2592.tar: contrib/library/gobo/tool/gec/runtime/c/eif_sig.c <==
/*
	description:

		"C functions used to implement class UNIX_SIGNALS"

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2006, Eric Bezault and others"
	license: "MIT License"
	date: "$Date: 2012-06-28 13:14:50 -0700 (Thu, 28 Jun 2012) $"
	revision: "$Revision: 89028 $"
*/

#ifndef EIF_SIG_C
#define EIF_SIG_C

#ifdef __cplusplus
extern "C" {
#endif

char esigdefined(long int sig) {
	/* TODO */
#ifdef EIF_WINDOWS
	GE_show_console();
#endif
	fprintf(stderr, "'esigdefined' in 'eif_sig.h' not implemented\n");
	return (char)'\0';
}

long esignum(void) {
	/* TODO */
#ifdef EIF_WINDOWS
	GE_show_console();
#endif
	fprintf(stderr, "'esignum' in 'eif_sig.h' not implemented\n");
	return (long)0;
}

void esigcatch(long int sig) {
	/* TODO */
#ifdef EIF_WINDOWS
	GE_show_console();
#endif
	fprintf(stderr, "'esigcatch' in 'eif_sig.h' not implemented\n");
}

void esigignore(long int sig) {
	/* TODO */
#ifdef EIF_WINDOWS
	GE_show_console();
#endif
	fprintf(stderr, "'esigignore' in 'eif_sig.h' not implemented\n");
}

void esigresall(void) {
	/* TODO */
#ifdef EIF_WINDOWS
	GE_show_console();
#endif
	fprintf(stderr, "'esigresall' in 'eif_sig.h' not implemented\n");
}

void esigresdef(long int sig) {
	/* TODO */
#ifdef EIF_WINDOWS
	GE_show_console();
#endif
	fprintf(stderr, "'esigresdef' in 'eif_sig.h' not implemented\n");
}

char esigiscaught(long int sig) {
	/* TODO */
#ifdef EIF_WINDOWS
	GE_show_console();
#endif
	fprintf(stderr, "'esigiscaught' in 'eif_sig.h' not implemented\n");
	return (char)'\0';
}

long esigmap(long int idx) {
	/* TODO */
#ifdef EIF_WINDOWS
	GE_show_console();
#endif
	fprintf(stderr, "'esigmap' in 'eif_sig.h' not implemented\n");
	return (long)0;
}

char* esigname(long int sig) {
	/* TODO */
#ifdef EIF_WINDOWS
	GE_show_console();
#endif
	fprintf(stderr, "'esigname' in 'eif_sig.h' not implemented\n");
	return (char*)0;
}

#ifdef __cplusplus
}
#endif

#endif

==> eiffelstudio-19.05.10.3187.tar: contrib/library/gobo/tool/gec/runtime/c/eif_sig.c <==
/*
	description:

		"C functions used to implement class UNIX_SIGNALS"

	system: "Gobo Eiffel Compiler"
	copyright: "Copyright (c) 2006-2017, Eric Bezault and others"
	license: "MIT License"
	date: "$Date: 2019-02-07 22:54:15 +0000 (Thu, 07 Feb 2019) $"
	revision: "$Revision: 102807 $"
*/

#ifndef EIF_SIG_C
#define EIF_SIG_C
#if defined(_MSC_VER) && (_MSC_VER >= 1020)
#pragma once
#endif

#ifndef EIF_SIG_H
#include "eif_sig.h"
#endif
#ifndef GE_CONSOLE_H
#include "ge_console.h"
#endif

#ifdef __cplusplus
extern "C" {
#endif

char esigdefined(long int sig)
{
	/* TODO */
	GE_show_console();
	fprintf(stderr, "'esigdefined' in 'eif_sig.h' not implemented\n");
	return (char)'\0';
}

long esignum(void)
{
	/* TODO */
	GE_show_console();
	fprintf(stderr, "'esignum' in 'eif_sig.h' not implemented\n");
	return (long)0;
}

void esigcatch(long int sig)
{
	/* TODO */
	GE_show_console();
	fprintf(stderr, "'esigcatch' in 'eif_sig.h' not implemented\n");
}

void esigignore(long int sig)
{
	/* TODO */
	GE_show_console();
	fprintf(stderr, "'esigignore' in 'eif_sig.h' not implemented\n");
}

void esigresall(void)
{
	/* TODO */
	GE_show_console();
	fprintf(stderr, "'esigresall' in 'eif_sig.h' not implemented\n");
}

void esigresdef(long int sig)
{
	/* TODO */
	GE_show_console();
	fprintf(stderr, "'esigresdef' in 'eif_sig.h' not implemented\n");
}

char esigiscaught(long int sig)
{
	/* TODO */
	GE_show_console();
	fprintf(stderr, "'esigiscaught' in 'eif_sig.h' not implemented\n");
	return (char)'\0';
}

long esigmap(long int idx)
{
	/* TODO */
	GE_show_console();
	fprintf(stderr, "'esigmap' in 'eif_sig.h' not implemented\n");
	return (long)0;
}

char* esigname(long int sig)
{
	/* TODO */
	GE_show_console();
	fprintf(stderr, "'esigname' in 'eif_sig.h' not implemented\n");
	return (char*)0;
}

#ifdef __cplusplus
}
#endif

#endif
